@@ -185,11 +185,22 @@ class MoveForm(forms.Form):
             self.instance.face = other.face
             for custom_field in other.cf:
                self.instance.cf[custom_field] = other.cf[custom_field]
+            
             # add tags from planned device if available
             try:
                 self.instance.tags.set(other.tags.get())
             except:
                 pass
+
+            # add bgp routing instances
+            try:
+                for bgp_routing_instance in other.bgp_routing_instances.all():
+                    bgp_routing_instance.device = self.instance
+                    bgp_routing_instance.validated_save()
+            except:
+                # no bgp routing instances
+                pass
+
             other.delete()
             self.instance.validated_save()
 
